@@ -3,9 +3,9 @@
 
 ##############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
+## This file is part of Taurus
 ## 
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ## 
@@ -24,6 +24,24 @@
 ##
 ##############################################################################
 import sys, os
+
+
+# declare some useful absolute paths
+_this_dir = os.path.dirname(os.path.abspath(__file__))
+_setup_dir = os.path.abspath(os.path.join(_this_dir, os.path.pardir, 
+                             os.path.pardir))
+_lib_dir = os.path.join(_setup_dir, 'lib')
+_doc_dir = os.path.join(_setup_dir, 'doc')
+_api_dir = os.path.join(_doc_dir, 'source', 'devel', 'api')
+_mock_path = os.path.join(_doc_dir, 'mock.zip')
+
+
+# append mock dir to the sys path (mocks will be used if needed)
+sys.path.append(_mock_path)
+    
+# Import code from src distribution
+sys.path.insert(0, os.path.abspath(_lib_dir))
+
 import taurus
 
 # If extensions (or modules to document with autodoc) are in another directory,
@@ -31,6 +49,59 @@ import taurus
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 sys.path.append(os.path.abspath('sphinxext'))
 
+# -- RTD hack -----------------------------------------------------------------
+# This code is to allow RTD to build the catalog and the api
+# it has no effect on local builds
+
+on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
+if on_rtd:    
+    import imp
+
+    def _build_catalog():
+        #import setup.py as a module
+        name = 'setup'
+        data = imp.find_module(name, [_setup_dir])
+        setupmod = imp.load_module(name, *data)
+        catalog = setupmod.build_catalog()
+        #build
+        fname = os.path.join(_doc_dir, 'source', 'devel', 'catalog.html')
+        catalog.fname = fname
+        catalog.builder_target_dir = _this_dir
+        catalog.thumbnails_source = os.path.join(_doc_dir, 'thumbnails.zip')
+        catalog.verbose = True
+        catalog.out = sys.stdout
+        catalog.run()
+        
+    def _build_doc_api():
+        #import auto_rst4api from the doc dir
+        name = 'auto_rst4api'
+        data = imp.find_module(name, [_doc_dir])
+        auto_rst4api = imp.load_module(name, *data)
+        API_Creator = auto_rst4api.Auto_rst4API_Creator
+        # prepare api creator
+        excl = ['_[^\.]*[^_]', '.*.extra_sardana', '.*.extra_pool', 
+                '.*.extra_macroexecutor', 'taurus.external']
+        rstCreator = API_Creator(exclude_patterns=excl,
+                                 templatespath=_doc_dir,
+                                 overwrite_old=True,
+                                 verbose=True)
+        # clean previously existing rst files
+        rstCreator.cleanAutogenerated(_api_dir)
+        # generate api
+        import taurus
+        r = rstCreator.documentModule('taurus', _api_dir)
+        # report
+        print("Auto Creation of API docs Finished with %i warnings:" % len(r))
+        for i in r:
+            print(i)
+        
+    #build the api and the catalog    
+    _build_catalog()
+    _build_doc_api()
+
+# ------------------------------------------------------------------------------
+
+
 # -- General configuration -----------------------------------------------------
 
 #autosummary_generate = True
@@ -243,7 +314,7 @@ intersphinx_mapping = {
     'http://docs.python.org/dev': None,
     'http://docs.scipy.org/doc/scipy/reference' : None,
     'http://docs.scipy.org/doc/numpy' : None,
-    'http://www.tango-controls.org/static/PyTango/latest/doc/html' : None,
+    'http://www.esrf.fr/computing/cs/tango/tango_doc/kernel_doc/pytango/latest/': None,
     'http://pyqt.sourceforge.net/Docs/PyQt4/' : None,
 }
 
